Learn R Programming

baymedr (version 0.1.1)

baymedr-package: baymedr: Computation of Bayes Factors for Common Biomedical Designs

Description

baymedr provides functions for the computation of Bayes factors for common biomedical research designs.

Arguments

Details

Package: baymedr
Type: Package
Version: 0.1.1
License: GPL-3
Date: 2021-03-26

At this point in time, baymedr entails tests for the following research designs with a continuous outcome measure:

See Also

Useful links: