The equivalence design has the following hypotheses: The null hypothesis
(i.e., H0) states that the population means of the experimental group (e.g.,
a new medication) and the control group (e.g., a placebo or an already
existing medication) are (practically) equivalent; the alternative hypothesis
(i.e., H1) states that the population means of the two groups are not
equivalent. The dependent variable must be continuous.
Since the main goal of equiv_bf is to establish equivalence,
the resulting Bayes factor quantifies evidence in favor of the null
hypothesis (i.e., BF01). Evidence for the alternative hypothesis can easily
be calculated by taking the reciprocal of the original Bayes factor (i.e.,
BF10 = 1 / BF01). Quantification of evidence in favor of the null hypothesis
is logically sound and legitimate within the Bayesian framework (see e.g.,
van Ravenzwaaij et al., 2019).
equiv_bf can be utilized to calculate a Bayes factor based on
raw data (i.e., if arguments x and y are defined) or summary
statistics (i.e., if arguments n_x, n_y, mean_x, and
mean_y are defined). In the latter case, either values for the
arguments sd_x and sd_y OR ci_margin and
ci_level can be supplied. Arguments with 'x' as a name or suffix
correspond to the control group, whereas arguments with 'y' as a name or
suffix correspond to the experimental group.
The equivalence interval can be specified with the argument interval.
However, it is not compulsory to specify an equivalence interval (see van
Ravenzwaaij et al., 2019). The default value of the argument interval
is 0, indicating a point null hypothesis. If an interval is preferred, the
argument interval can be set in two ways: A symmetric interval
can be defined by either specifying a numeric vector of length one (e.g., 0.1,
which is converted to c(-0.1, 0.1)) or a numeric vector of length two (e.g.,
c(-0.1, 0.1)); an asymmetric interval can be defined by specifying a
numeric vector of length two (e.g., c(-0.1, 0.2)). It can be specified
whether the equivalence interval (i.e., interval) is given in
standardized or unstandardized units with the interval_std argument,
where TRUE, corresponding to standardized units, is the default.
For the calculation of the Bayes factor, a Cauchy prior density centered on 0
is chosen for the effect size under the alternative hypothesis. The standard
Cauchy distribution, with a location parameter of 0 and a scale parameter of
1, resembles a standard Normal distribution, except that the Cauchy
distribution has less mass at the center but heavier tails (Liang et al.,
2008; Rouder et al., 2009). The argument prior_scale specifies the
width of the Cauchy prior, which corresponds to half of the interquartile
range. Thus, by adjusting the Cauchy prior scale with prior_scale,
different ranges of expected effect sizes can be emphasized. The default
prior scale is set to r = 1 / sqrt(2).
equiv_bf creates an S4 object of class
'>baymedrEquivalence, which has multiple slots/entries (e.g.,
type of data, prior scale, Bayes factor, etc.; see Value). If it is desired
to store or extract solely the Bayes factor, the user can do this with
get_bf, by setting the S4 object as an argument (see Examples).